using System;
using Server;
using Server.Network;
using Server.Scripts.CraftSystems;

namespace Server.Scripts.Items.Tools
{
	public abstract class BaseTool : Item
	{
		private int m_Durability;

		public abstract CraftSystem CraftSystem{ get; }

		public BaseTool( int itemID ) : this( 50, itemID )
		{
		}

		public BaseTool( int durability, int itemID ) : base( itemID )
		{
			m_Durability = durability;
		}

		public BaseTool( Serial serial ) : base( serial )
		{
		}

		public override void OnSingleClick( Mobile from )
		{
			this.LabelToAffix( from, 1017323, AffixType.Append, ": " + m_Durability.ToString() ); // Durability

			base.OnSingleClick( from );
		}

		public override void OnDoubleClick( Mobile from )
		{
			CraftSystem system = this.CraftSystem;

			if ( system.CanCraft( from ) )
				from.SendGump( new CraftGump( from, system ) );
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version

			writer.Write( (int) m_Durability );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();

			switch ( version )
			{
				case 0:
				{
					m_Durability = reader.ReadInt();
					break;
				}
			}
		}
	}
}