using System;
using System.Text;
using Server.Gumps;
using Server.Network;

namespace Server.Scripts.Misc.TestCenter
{
	public class TCSetSkills
	{
		public static void Initialize()
		{
			// Register our speech handler
			EventSink.Speech += new SpeechEventHandler( EventSink_Speech );
		}

		private static void EventSink_Speech( SpeechEventArgs args )
		{
			string toUpper = args.Speech.ToUpper();

			if ( !args.Handled && toUpper.StartsWith( "SET" ) )
			{
				Mobile from = args.Mobile;

				string[] split = toUpper.Split( ' ' );

				if ( split.Length == 3 )
				{
					try
					{
						string name = split[1];
						double value = Convert.ToDouble( split[2] );

						switch ( name )
						{
							case "STR":
							{
								ChangeStrength( from, (int)value );
								break;
							}
							case "DEX":
							{
								ChangeDexterity( from, (int)value );
								break;
							}
							case "INT":
							{
								ChangeIntelligence( from, (int)value );
								break;
							}
							default:
							{
								ChangeSkill( from, name, value );
								break;
							}
						}
					}
					catch
					{
					}
				}
			}
		}

		private static void ChangeStrength( Mobile from, int value )
		{
			if ( value < 10 || value > 125 )
			{
				from.SendLocalizedMessage( 1005628 ); // Stats range between 10 and 125.
			}
			else
			{
				if ( (value + from.RawDex + from.RawInt) > from.StatCap )
				{
					from.SendLocalizedMessage( 1005629 ); // You can not exceed the stat cap.  Try setting another stat lower first.
				}
				else
				{
					from.RawStr = value;
					from.SendLocalizedMessage( 1005630 ); // Your stats have been adjusted.
				}
			}
		}

		private static void ChangeDexterity( Mobile from, int value )
		{
			if ( value < 10 || value > 125 )
			{
				from.SendLocalizedMessage( 1005628 ); // Stats range between 10 and 125.
			}
			else
			{
				if ( (from.RawStr + value + from.RawInt) > from.StatCap )
				{
					from.SendLocalizedMessage( 1005629 ); // You can not exceed the stat cap.  Try setting another stat lower first.
				}
				else
				{
					from.RawDex = value;
					from.SendLocalizedMessage( 1005630 ); // Your stats have been adjusted.
				}
			}
		}

		private static void ChangeIntelligence( Mobile from, int value )
		{
			if ( value < 10 || value > 125 )
			{
				from.SendLocalizedMessage( 1005628 ); // Stats range between 10 and 125.
			}
			else
			{
				if ( (from.RawStr + from.RawDex + value) > from.StatCap )
				{
					from.SendLocalizedMessage( 1005629 ); // You can not exceed the stat cap.  Try setting another stat lower first.
				}
				else
				{
					from.RawInt = value;
					from.SendLocalizedMessage( 1005630 ); // Your stats have been adjusted.
				}
			}
		}

		private static void ChangeSkill( Mobile from, string name, double value )
		{
			SkillName index;

			try
			{
				index = (SkillName)Enum.Parse( typeof( SkillName ), name, true );
			}
			catch
			{
				from.SendLocalizedMessage( 1005631 ); // You have specified an invalid skill to set.
				return;
			}

			Skill skill = from.Skills[index];

			if ( skill != null )
			{
				if ( value < 0 || value > skill.Cap )
				{
					from.SendMessage( String.Format( "Your skill in {0} is capped at {1:F1}.", skill.Info.Name, skill.Cap ) );
				}
				else
				{
					int newFixedPoint = (int)(value * 10.0);
					int oldFixedPoint = skill.BaseFixedPoint;

					if ( ((skill.Owner.Total - oldFixedPoint) + newFixedPoint) > 7000 )
					{
						from.SendMessage( "You can not exceed the skill cap.  Try setting another skill lower first." );
					}
					else
					{
						skill.BaseFixedPoint = newFixedPoint;
					}
				}
			}
			else
			{
				from.SendLocalizedMessage( 1005631 ); // You have specified an invalid skill to set.
			}
		}
	}
}