using System;
using Server.Scripts.Mobiles.Monsters.Magical;
using Server.Network;
using Server.Targeting;

namespace Server.Spells.Eighth
{
	public class EnergyVortexSpell : Spell
	{
		private static SpellInfo m_Info = new SpellInfo(
				"Energy Vortex", "Vas Corp Por",
				SpellCircle.Eighth,
				Reagent.Bloodmoss,
				Reagent.BlackPearl,
				Reagent.MandrakeRoot,
				Reagent.Nightshade
			);

		public EnergyVortexSpell( Mobile caster, Server.Items.SpellScroll scroll ) : base( caster, scroll, m_Info )
		{
		}

		public override void OnCast()
		{
			Caster.Target = new InternalTarget( this );
		}

		public void Target( IPoint3D p )
		{
			if ( !Caster.CanSee( p ) )
			{
				Caster.SendLocalizedMessage( 500237 ); // Target can not be seen.
			}
			else if ( CheckSequence() )
			{
				EnergyVortex ev = new EnergyVortex();

				ev.Map = Caster.Map;
				ev.Location = new Point3D( p );

				Effects.PlaySound( p, ev.Map, 0x212 );
			}

			FinishSequence();
		}

		private class InternalTarget : Target
		{
			private EnergyVortexSpell m_Owner;

			public InternalTarget( EnergyVortexSpell owner ) : base( 12, true, TargetFlags.None )
			{
				m_Owner = owner;
			}

			protected override void OnTarget( Mobile from, object o )
			{
				if ( o is IPoint3D )
				{
					m_Owner.Target( (IPoint3D)o );
				}
			}

			protected override void OnTargetFinish( Mobile from )
			{
				m_Owner.FinishSequence();
			}
		}
	}
}